ReadResponse

Enum ReadResponse 

pub enum ReadResponse {
Show 34 variants UsageInfo(u64), Tip(Option<(Height, Hash)>), TipPoolValues { tip_height: Height, tip_hash: Hash, value_balance: ValueBalance<NonNegative>, }, BlockInfo(Option<BlockInfo>), Depth(Option<u32>), Block(Option<Arc<Block>>), BlockAndSize(Option<(Arc<Block>, usize)>), BlockHeader { header: Arc<Header>, hash: Hash, height: Height, next_block_hash: Option<Hash>, }, Transaction(Option<MinedTx>), AnyChainTransaction(Option<AnyTx>), TransactionIdsForBlock(Option<Arc<[Hash]>>), AnyChainTransactionIdsForBlock(Option<(Arc<[Hash]>, bool)>), TransactionId(Option<Hash>), BlockLocator(Vec<Hash>), BlockHashes(Vec<Hash>), BlockHeaders(Vec<CountedHeader>), UnspentBestChainUtxo(Option<Utxo>), AnyChainUtxo(Option<Utxo>), SaplingTree(Option<Arc<NoteCommitmentTree>>), OrchardTree(Option<Arc<NoteCommitmentTree>>), SaplingSubtrees(BTreeMap<NoteCommitmentSubtreeIndex, NoteCommitmentSubtreeData<Node>>), OrchardSubtrees(BTreeMap<NoteCommitmentSubtreeIndex, NoteCommitmentSubtreeData<Node>>), AddressBalance { balance: Amount<NonNegative>, received: u64, }, AddressesTransactionIds(BTreeMap<TransactionLocation, Hash>), AddressUtxos(AddressUtxos), ValidBestChainTipNullifiersAndAnchors, BestChainNextMedianTimePast(DateTime32), BlockHash(Option<Hash>), ChainInfo(GetBlockTemplateChainInfo), SolutionRate(Option<u128>), ValidBlockProposal, TipBlockSize(Option<usize>), NonFinalizedBlocksListener(NonFinalizedBlocksListener), IsTransparentOutputSpent(bool),
}
A response to a read-only ReadStateService’s ReadRequest.

Variants



UsageInfo(u64)

Response to ReadRequest::UsageInfo with the current best chain tip.



Tip(Option<(Height, Hash)>)

Response to ReadRequest::Tip with the current best chain tip.



TipPoolValues

Response to ReadRequest::TipPoolValues with the current best chain tip and its ValueBalance.

Fields

tip_height: Height

The current best chain tip height.

tip_hash: Hash

The current best chain tip hash.

value_balance: ValueBalance<NonNegative>

The value pool balance at the current best chain tip.



BlockInfo(Option<BlockInfo>)

Response to ReadRequest::BlockInfo with the block info after the specified block.



Depth(Option<u32>)

Response to ReadRequest::Depth with the depth of the specified block.



Block(Option<Arc<Block>>)

Response to ReadRequest::Block with the specified block.



BlockAndSize(Option<(Arc<Block>, usize)>)

Response to ReadRequest::BlockAndSize with the specified block and serialized size.



BlockHeader

The response to a BlockHeader request.

Fields

header: Arc<Header>

The header of the requested block

hash: Hash

The hash of the requested block

height: Height

The height of the requested block

next_block_hash: Option<Hash>

The hash of the next block after the requested block



Transaction(Option<MinedTx>)

Response to ReadRequest::Transaction with the specified transaction.



AnyChainTransaction(Option<AnyTx>)

Response to Request::Transaction with the specified transaction.



TransactionIdsForBlock(Option<Arc<[Hash]>>)

Response to ReadRequest::TransactionIdsForBlock, with an list of transaction hashes in block order, or None if the block was not found.



AnyChainTransactionIdsForBlock(Option<(Arc<[Hash]>, bool)>)

Response to ReadRequest::AnyChainTransactionIdsForBlock, with an list of transaction hashes in block order and a flag indicating if the block is in the best chain, or None if the block was not found.



TransactionId(Option<Hash>)

Response to ReadRequest::SpendingTransactionId, with an list of transaction hashes in block order, or None if the block was not found.



BlockLocator(Vec<Hash>)

Response to ReadRequest::BlockLocator with a block locator object.



BlockHashes(Vec<Hash>)

The response to a FindBlockHashes request.



BlockHeaders(Vec<CountedHeader>)

The response to a FindBlockHeaders request.



UnspentBestChainUtxo(Option<Utxo>)

The response to a UnspentBestChainUtxo request, from verified blocks in the best non-finalized chain, or the finalized chain.



AnyChainUtxo(Option<Utxo>)

The response to an AnyChainUtxo request, from verified blocks in any non-finalized chain, or the finalized chain.

This response is purely informational, there is no guarantee that the UTXO remains unspent in the best chain.



SaplingTree(Option<Arc<NoteCommitmentTree>>)

Response to ReadRequest::SaplingTree with the specified Sapling note commitment tree.



OrchardTree(Option<Arc<NoteCommitmentTree>>)

Response to ReadRequest::OrchardTree with the specified Orchard note commitment tree.



SaplingSubtrees(BTreeMap<NoteCommitmentSubtreeIndex, NoteCommitmentSubtreeData<Node>>)

Response to ReadRequest::SaplingSubtrees with the specified Sapling note commitment subtrees.



OrchardSubtrees(BTreeMap<NoteCommitmentSubtreeIndex, NoteCommitmentSubtreeData<Node>>)

Response to ReadRequest::OrchardSubtrees with the specified Orchard note commitment subtrees.



AddressBalance

Response to ReadRequest::AddressBalance with the total balance of the addresses, and the total received funds, including change.

Fields

balance: Amount<NonNegative>

The total balance of the addresses.

received: u64

The total received funds in zatoshis, including change.



AddressesTransactionIds(BTreeMap<TransactionLocation, Hash>)

Response to ReadRequest::TransactionIdsByAddresses with the obtained transaction ids, in the order they appear in blocks.



AddressUtxos(AddressUtxos)

Response to ReadRequest::UtxosByAddresses with found utxos and transaction data.



ValidBestChainTipNullifiersAndAnchors

Response to ReadRequest::CheckBestChainTipNullifiersAndAnchors.

Does not check transparent UTXO inputs



BestChainNextMedianTimePast(DateTime32)

Response to ReadRequest::BestChainNextMedianTimePast. Contains the median-time-past for the next block on the best chain.



BlockHash(Option<Hash>)

Response to ReadRequest::BestChainBlockHash with the specified block hash.



ChainInfo(GetBlockTemplateChainInfo)

Response to ReadRequest::ChainInfo with the state information needed by the getblocktemplate RPC method.



SolutionRate(Option<u128>)



ValidBlockProposal



TipBlockSize(Option<usize>)



NonFinalizedBlocksListener(NonFinalizedBlocksListener)



IsTransparentOutputSpent(bool)